#!/bin/bash

# This script allows you to quickly change your bind9 configuration:
#     - define an internal domain and bind it to 127.0.0.1
#     - add SRV records to use this domain with your local XMPP server
#
# BE SURE TO BACKUP /etc/bind AND /var/cache/bind BEFORE USING THIS SCRIPT!
#
# Configuration files based on:
#     - http://www.madboa.com/geek/soho-bind
#     - http://wiki.xmpp.org/web/SRV_Records
#     - http://prosody.im/doc/dns
#
# For this to work, Prosody configuration must define the domain as a VirtualHost.
# It is also assumed that the Prosody "directory" option is set to "/var/cache/bind".
#
# Finally, you may want to modify the SàT configuration file to set the option
# "new_account_domain" to that domain passed in $1 in order to register new
# account from Libervia, and the "jid" option of sat_pubsub should be set to
# "sat-pubsub.<domain>" for the microblogging feature to work.

if [ $# -lt 2 ]; then
  echo "Usage: `basename $0` <domain> <c2s_port>"
  exit 1
fi

HOSTNAME=`cat /etc/hostname`
DOMAIN=$1
C2S_PORT=$2
DATE=`date +%s`

mkdir -p /tmp/$DATE/
cp -r template/* /tmp/$DATE/
cd /tmp/$DATE
for FILE in `find . -type f`; do
    sed -e s/\<domain\>/$DOMAIN/g -e s/\<hostname\>/$HOSTNAME/g -e s/\<date\>/$DATE/g -e s/\<c2s_port\>/$C2S_PORT/g $FILE > `echo $FILE | sed -e 's/^.//' -e s/my.domain/$DOMAIN/`
done
/etc/init.d/bind9 restart
tail /var/log/syslog
